@@ -1132,11 +1132,11 @@ sub out_tag(\@$) {
 	@ret
 }
 
-=pod
-Разбивает текст на страницы с учётом html-тегов
 
-1. html-тег должен быть так же разнесён на страницы.
-=cut
+# Разбивает текст на страницы с учётом html-тегов
+#
+# 1. html-тег должен быть так же разнесён на страницы.
+#
 sub split_on_pages(@) {
 	my ($html, $symbols_on_page, $by) = @_;
 
